@@ -7,13 +7,12 @@ from dask import dataframe as dd
 
 def create_dask_df(database=None,
                    table=None,
-                   gcs_bucket=None,
-                   in_airflow=True):
+                   gcs_bucket=None):
 
     curr_date = datetime.now().strftime('%Y-%m-%d')
     filename = f'{table}-extract-{curr_date}.csv'
 
-    data_folder = Variable.get('data_folder') if in_airflow else './'
+    data_folder = Variable.get('data_folder')
     data_path = f'{data_folder}/{database}/{table}/{filename}'
 
     storage_client = storage.Client()
